isci: convert phy_startup_timer to sci_timer

Signed-off-by: Edmund Nadolski <edmund.nadolski@intel.com>
Signed-off-by: Dan Williams <dan.j.williams@intel.com>
diff --git a/drivers/scsi/isci/host.h b/drivers/scsi/isci/host.h
index 8080866..9fd47b4 100644
--- a/drivers/scsi/isci/host.h
+++ b/drivers/scsi/isci/host.h
@@ -271,15 +271,14 @@
 
 	/* Phy Startup Data */
 	/**
-	 * This field is the driver timer handle for controller phy request startup.
-	 * On controller start the controller will start each PHY individually in
-	 * order of phy index.
+	 * Timer for controller phy request startup. On controller start the
+	 * controller will start each PHY individually in order of phy index.
 	 */
-	void *phy_startup_timer;
+	struct sci_timer phy_timer;
 
 	/**
 	 * This field is set when the phy_startup_timer is running and is cleared when
 	 * the phy_startup_timer is stopped.
 	 */
 	bool phy_startup_timer_pending;
@@ -271,15 +271,14 @@
 
 	/**
-	 * This field is set when the phy_startup_timer is running and is cleared when
-	 * the phy_startup_timer is stopped.
+	 * This field is set when the phy_timer is running and is cleared when
+	 * the phy_timer is stopped.
 	 */
 	bool phy_startup_timer_pending;